==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/PaneDragOverEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { DockManagerPane } from "./DockManagerPane";
import { ContentPane } from "./ContentPane";
import { PaneDragAction } from "./PaneDragAction";
/**
 * @hidden
 */
export let PaneDragOverEventArgsDetail = /*@__PURE__*/ (() => {
    class PaneDragOverEventArgsDetail extends Base {
        constructor() {
            super(...arguments);
            this.d = new WCNativeHelper();
            this.g = null;
        }
        get e() {
            return this.d;
        }
        get nativeElement() {
            return this.g;
        }
        set nativeElement(a) {
            this.g = a;
            this.d.n = this.g;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get b() {
            let ret_ = this.e.l("sourcePane", (a) => DockManagerPane.createFromNative(a));
            return ret_;
        }
        set b(a) {
            let value_ = a;
            this.e.u("sourcePane", value_);
        }
        get a() {
            let ret_ = this.e.l("panes", (a) => new ContentPane());
            return ret_;
        }
        set a(a) {
            let value_ = a;
            this.e.u("panes", value_);
        }
        get c() {
            let ret_ = this.e.l("action", (a) => new PaneDragAction());
            return ret_;
        }
        set c(a) {
            let value_ = a;
            this.e.u("action", value_);
        }
        get f() {
            let ret_ = this.e.m("isValid");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.e.u("isValid", value_);
        }
    }
    PaneDragOverEventArgsDetail.$t = /*@__PURE__*/ markType(PaneDragOverEventArgsDetail, 'PaneDragOverEventArgsDetail');
    return PaneDragOverEventArgsDetail;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/PaneDragOverEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { DockManagerPane } from "./DockManagerPane";
import { ContentPane } from "./ContentPane";
import { PaneDragAction } from "./PaneDragAction";
/**
 * @hidden
 */
export let PaneDragOverEventArgsDetail = /*@__PURE__*/ (() => {
    class PaneDragOverEventArgsDetail extends Base {
        constructor() {
            super(...arguments);
            this.d = new WCNativeHelper();
            this.g = null;
        }
        get e() {
            return this.d;
        }
        get nativeElement() {
            return this.g;
        }
        set nativeElement(a) {
            this.g = a;
            this.d.o = this.g;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get b() {
            let ret_ = this.e.m("sourcePane", (a) => DockManagerPane.createFromNative(a));
            return ret_;
        }
        set b(a) {
            let value_ = a;
            this.e.v("sourcePane", value_);
        }
        get a() {
            let ret_ = this.e.m("panes", (a) => new ContentPane());
            return ret_;
        }
        set a(a) {
            let value_ = a;
            this.e.v("panes", value_);
        }
        get c() {
            let ret_ = this.e.m("action", (a) => new PaneDragAction());
            return ret_;
        }
        set c(a) {
            let value_ = a;
            this.e.v("action", value_);
        }
        get f() {
            let ret_ = this.e.n("isValid");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.e.v("isValid", value_);
        }
    }
    PaneDragOverEventArgsDetail.$t = /*@__PURE__*/ markType(PaneDragOverEventArgsDetail, 'PaneDragOverEventArgsDetail');
    return PaneDragOverEventArgsDetail;
})();
